package com.muyu.marketing.domain.req;

import com.fasterxml.jackson.annotation.JsonFormat;
import com.muyu.marketing.domain.model.ActivityTeamInfoSaveModel;
import com.muyu.marketing.domain.model.TeamSkuInfoModel;
import lombok.AllArgsConstructor;
import lombok.Data;
import lombok.NoArgsConstructor;
import lombok.experimental.SuperBuilder;
import org.springframework.format.annotation.DateTimeFormat;

import javax.validation.constraints.NotNull;
import java.util.Date;
import java.util.List;

/**
 * @description: 添加拼团活动入参
 **/
@Data
@AllArgsConstructor
@NoArgsConstructor
@SuperBuilder
public class ActivityTeamInfoSaveReq {
    /**
     * 商品id
     */
    @NotNull(message = "商品id不能为空")
    private Long productId;
    /**
     * 商品图片
     */
    @NotNull(message = "商品照片不能为空")
    private String productImage;
    /**
     * 活动名称
     */
    @NotNull(message = "活动名称不能为空")
    private String name;
    /**
     * 活动简介
     */
    @NotNull(message = "活动简介不能为空")
    private String introduction;
    /**
     * 商品单位
     */
    @NotNull(message = "商品单位不能为空")
    private String unit;
    /**
     * 商品轮播图
     */
    @NotNull(message = "商品轮播图不能为空")
    private List<String> imageList;
    /**
     * 活动结束时间
     */
    @DateTimeFormat(pattern = "yyyy-MM-dd HH:mm:ss")
    @JsonFormat(pattern = "yyyy-MM-dd HH:mm:ss")
    @NotNull(message = "活动结束时间不能为空")
    private Date endTime;
    /**
     * 排序
     */
    @NotNull(message = "排序不能为空")
    private Integer sort;
    /**
     * 详情
     */
    @NotNull(message = "详情不能为空")
    private String content;
    /**
     * 状态
     */
    @NotNull(message = "状态不能为空")
    private String status;
    /**
     * 拼团类型
     */
    @NotNull(message = "拼团类型不能为空")
    private String strategyType;
    /**
     * 拼团id
     */
    @NotNull(message = "拼团id不能为空")
    private Long strategyId;
    /**
     * 商品sku
     */
    @NotNull(message = "商品sku不能为空")
    private List<TeamSkuInfoModel> projectSkuInfoList;

    /**
     *构造方法
     */
    public ActivityTeamInfoSaveModel saveModel(){
        return ActivityTeamInfoSaveModel.builder()
                .productId(productId)
                .productImage(productImage)
                .name(name)
                .introduction(introduction)
                .unit(unit)
                .imageList(imageList)
                .endTime(endTime)
                .sort(sort)
                .content(content)
                .status(status)
                .strategyType(strategyType)
                .strategyId(strategyId)
                .projectSkuInfoList(projectSkuInfoList)
//                .content(content)
//                .strategyType(strategyType)
                .build();
    }
}
