package com.muyu.marketing.controller;

import com.github.pagehelper.Page;
import com.muyu.common.core.domain.Result;
import com.muyu.common.core.utils.PageUtils;
import com.muyu.common.core.web.page.TableDataInfo;
import com.muyu.common.security.annotation.EnableMyFeignClients;
import com.muyu.marketing.domain.model.ActivityTeamInfoListModel;
import com.muyu.marketing.domain.req.ActivityTeamInfoSaveReq;
import com.muyu.marketing.domain.req.TeamInfoListReq;
import com.muyu.marketing.domain.resp.TeamInfoResp;
import com.muyu.marketing.service.ActivityTeamInfoService;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import java.util.List;


@RestController
@RequestMapping("/team")
@Slf4j
//@EnableMyFeignClients(basePackages = "com.muyu")
public class ActivityTeamController {
    @Autowired
    private ActivityTeamInfoService activityTeamInfoService;

    /**
     * 检查404
     */
    public ActivityTeamController() {
        log.info("商品拼团控制层{}",getClass().getName());
    }
    /**
     * 列表
     */
    @PostMapping("list")
    public Result<TableDataInfo<TeamInfoResp>> list(@RequestBody TeamInfoListReq teamInfoListReq){
        //分页
        Page<ActivityTeamInfoListModel> page = PageUtils.startPage(teamInfoListReq.getPageNum(), teamInfoListReq.getPageSize());
        List<ActivityTeamInfoListModel> rows = activityTeamInfoService.list(teamInfoListReq.buildModel()).getRows();
        //将数据模型转换为响应模型 利用Stream流把数据转换为响应列表
        List<TeamInfoResp> activityTeamInfoResps = rows.stream().map(activityTeamInfoListModel -> {
            return TeamInfoResp.respBuild(activityTeamInfoListModel);
        }).toList();
        //创建分页信息对象
        TableDataInfo<TeamInfoResp> teamInfoRespTableDataInfo = new TableDataInfo<>();
        teamInfoRespTableDataInfo.setRows(activityTeamInfoResps);
        teamInfoRespTableDataInfo.setTotal(page.getTotal());
        return Result.success(teamInfoRespTableDataInfo);
    }

    /**
     * 添加拼团活动
     */
    @PostMapping("addTeam")
    public Result addTeam(@Validated @RequestBody ActivityTeamInfoSaveReq activityTeamInfoSaveReq){
        //判断是否添加成功
        boolean success = activityTeamInfoService.addTeam(activityTeamInfoSaveReq.saveModel());
        if (success){
            return Result.success("添加成功");
        }
        return Result.error("添加失败");
    }
}
