package com.muyu.marketing.service.impl;

import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.muyu.common.core.utils.StringUtils;
import com.muyu.common.core.web.page.TableDataInfo;
import com.muyu.marketing.domain.ActivityTeamInfo;
import com.muyu.marketing.domain.ActivityTeamOpenInfo;
import com.muyu.marketing.domain.ActivityTeamProductSkuInfo;
import com.muyu.marketing.domain.model.*;
import com.muyu.marketing.mapper.ActivityTeamInfoMapper;
import com.muyu.marketing.service.ActivityTeamInfoService;
import com.muyu.marketing.service.ActivityTeamOpenInfoService;
import com.muyu.marketing.service.ActivityTeamProductSkuInfoService;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.List;
@Service
@Slf4j
public class ActivityTeamInfoServiceImpl extends ServiceImpl<ActivityTeamInfoMapper, ActivityTeamInfo>
implements ActivityTeamInfoService {
    @Autowired
    private ActivityTeamOpenInfoService activityTeamOpenInfoService;
    @Autowired
    private ActivityTeamProductSkuInfoService activityTeamProductSkuInfoService;


    @Override
    public TableDataInfo<ActivityTeamInfoListModel> list(ActivityTeamInfoListQueryModel activityTeamInfoListQueryModel) {
        LambdaQueryWrapper<ActivityTeamInfo> queryWrapper = new LambdaQueryWrapper<>();
        queryWrapper.like(StringUtils.isNotEmpty(
                activityTeamInfoListQueryModel.getKeyWord()),
                ActivityTeamInfo::getName,
                activityTeamInfoListQueryModel.getKeyWord()
        );
        queryWrapper.like(StringUtils.isNotEmpty(activityTeamInfoListQueryModel.getStatus()),
                ActivityTeamInfo::getStatus,
                activityTeamInfoListQueryModel.getStatus()
        );
        Page<ActivityTeamInfo> pages = this.page(activityTeamInfoListQueryModel.bulidPage(), queryWrapper);
        List<ActivityTeamInfo> records = pages.getRecords();
        List<ActivityTeamInfoListModel> list = records.stream().map(activityTeamInfo -> ActivityTeamInfoListModel
                .domainBuild(activityTeamInfo, (activityTeamInfoListModelBuilder -> {
                    Long teamOpenNum = activityTeamOpenInfoService.getTeamOpenTypeNumberByTeamId(activityTeamInfo.getId());
                    Long teamInNum = activityTeamOpenInfoService.getTeamOpenTypeNumberByTeamId(activityTeamInfo.getId());
                    TeamProductDiscountPriceModel discountPriceModel = activityTeamProductSkuInfoService.discountPrice(activityTeamInfo.getId());
                    TeamStockModel stock = activityTeamProductSkuInfoService.getStock(activityTeamInfo.getId());
                    return activityTeamInfoListModelBuilder
                            .addTeamNumber(teamInNum)
                            .openTeamNumber(teamInNum)
                            .attendNumber(teamOpenNum + teamInNum)
                            .teamPrice(discountPriceModel.getProductPrice())
                            .teamStock(stock.getTeamStock())
                            .remainStock(stock.getRemainStock())
                            .build();
                }))).toList();
        return TableDataInfo.<ActivityTeamInfoListModel>builder()
                .total(pages.getTotal())
                .rows(list)
                .build();
    }

    /**
     * 添加拼团信息
     */
    @Override
    public boolean addTeam(ActivityTeamInfoSaveModel activityTeamInfoSaveModel) {
        //调用拼团信息表的构造方法 添加
        ActivityTeamInfo activityTeamInfo = ActivityTeamInfo.saveActivityTeamInfo(activityTeamInfoSaveModel);
        //调用添加方法
        boolean save = this.save(activityTeamInfo);
        //判断添加的时候，添加规格sku列表的数据 调用集合
        if (save){
            List<TeamSkuInfoModel> projectSkuInfoList = activityTeamInfoSaveModel.getProjectSkuInfoList();
            //利用steam流遍历集合，把集合中的数据进行转换，转换成对象 进行批量添加
            // 批量添加方法
            activityTeamProductSkuInfoService.saveBatch(projectSkuInfoList.stream().map(projuctSkuInfo -> ActivityTeamProductSkuInfo.TeamSkuInfoBuild(projuctSkuInfo, (activityTeamProductSkuInfoBuilder -> {
                LambdaQueryWrapper<ActivityTeamOpenInfo> queryWrapper = new LambdaQueryWrapper<>();
                queryWrapper.eq(ActivityTeamOpenInfo::getTeamId,activityTeamInfo.getId());
                long count = activityTeamOpenInfoService.count(queryWrapper);
                return activityTeamProductSkuInfoBuilder
                        //商品表的ID
                        .teamId(activityTeamInfo.getId())
                        //sku的剩余库存
                        .teamStock(projuctSkuInfo.getTeamStock() - count)
                        .build();
            }))).toList());

        }

        return save;
    }
}
