package com.muyu.product.domain.resp;

import com.baomidou.mybatisplus.annotation.IdType;
import com.baomidou.mybatisplus.annotation.TableId;
import com.baomidou.mybatisplus.annotation.TableName;
import com.muyu.common.core.annotation.Excel;
import com.muyu.product.domain.AttributeGroup;
import com.muyu.product.domain.AttributeInfo;
import com.muyu.product.domain.BrandInfo;
import com.muyu.product.domain.model.CategoryInfoSaveModel;
import com.muyu.product.domain.req.CategoryInfoEditReq;
import com.muyu.product.domain.req.CategoryInfoQueryReq;
import com.muyu.product.domain.req.CategoryInfoSaveReq;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;
import lombok.AllArgsConstructor;
import lombok.Data;
import lombok.EqualsAndHashCode;
import lombok.NoArgsConstructor;
import lombok.experimental.SuperBuilder;

import java.util.Date;
import java.util.List;
import java.util.function.Supplier;

@Data
@SuperBuilder
@NoArgsConstructor
@AllArgsConstructor
@TableName("category_info")
@EqualsAndHashCode(callSuper = false)
@ApiModel(value = "CategoryInfo", description = "品类信息")
public class CategoryInfoUpdResp {
    /** 主键 */
    @TableId(value = "id", type = IdType.AUTO)
    @ApiModelProperty(name = "主键", value = "主键")
    private Long id;

    /** 品类名称 */
    @Excel(name = "品类名称")
    @ApiModelProperty(name = "品类名称", value = "品类名称", required = true)
    private String name;

    /** 图片 */
    @Excel(name = "图片")
    @ApiModelProperty(name = "图片", value = "图片", required = true)
    private String image;

    /** 是否启用 */
    @Excel(name = "是否启用")
    @ApiModelProperty(name = "是否启用", value = "是否启用", required = true)
    private String start;

    /** 介绍 */
    @Excel(name = "介绍")
    @ApiModelProperty(name = "介绍", value = "介绍")
    private String introduction;

    /** 父级ID */
    @ApiModelProperty(name = "父级ID", value = "父级ID")
    private Long parentId;

    /**
     * 属性集合
     */
    @Excel(name = "属性集合")
    @ApiModelProperty(name = "属性集合", value = "属性集合")
    private List<AttributeInfo> attributeInfoList;

    /**
     * 属性组集合
     */
    @Excel(name = "属性组集合")
    @ApiModelProperty(name = "属性组集合", value = "属性组集合")
    private List<AttributeGroup> attributeGroupList;

    /**
     * 品牌集合
     */
    @Excel(name = "品牌集合")
    @ApiModelProperty(name = "品牌集合", value = "品牌集合")
    private List<BrandInfo> brandInfoList;

    /**
     * 查询构造器
     */
    public static CategoryInfoUpdResp queryBuild(CategoryInfoQueryReq categoryInfoQueryReq) {
        return CategoryInfoUpdResp.builder()
                .name(categoryInfoQueryReq.getName())
                .image(categoryInfoQueryReq.getImage())
                .start(categoryInfoQueryReq.getStart())
                .introduction(categoryInfoQueryReq.getIntroduction())
                .build();
    }

    /**
     * 添加构造器
     */
    public static CategoryInfoUpdResp saveBuild(CategoryInfoSaveReq categoryInfoSaveReq, Supplier<String> supplier) {
        return CategoryInfoUpdResp.builder()
                .name(categoryInfoSaveReq.getName())
                .image(categoryInfoSaveReq.getImage())
                .start(categoryInfoSaveReq.getStart())
                .introduction(categoryInfoSaveReq.getIntroduction())
                .parentId(categoryInfoSaveReq.getParentId())
                .build();
    }

    /**
     * 修改构造器
     */
    public static CategoryInfoUpdResp editBuild(Long id, CategoryInfoEditReq categoryInfoEditReq) {
        return CategoryInfoUpdResp.builder()
                .id(id)
                .name(categoryInfoEditReq.getName())
                .image(categoryInfoEditReq.getImage())
                .start(categoryInfoEditReq.getStart())
                .introduction(categoryInfoEditReq.getIntroduction())
                .build();
    }

    public static CategoryInfoUpdResp saveModelBuild(CategoryInfoSaveModel categoryInfoSaveModel) {
        return CategoryInfoUpdResp.builder()
                .name(categoryInfoSaveModel.getName())
                .image(categoryInfoSaveModel.getImage())
                .start(categoryInfoSaveModel.getStart())
                .introduction(categoryInfoSaveModel.getIntroduction())
                .parentId(categoryInfoSaveModel.getParentId())
                .build();
    }

}
